==============
Aldryn Gallery
==============

.. image:: https://travis-ci.org/aldryn/aldryn-gallery.svg?branch=master
    :target: https://travis-ci.org/aldryn/aldryn-gallery

.. image:: https://img.shields.io/coveralls/aldryn/aldryn-gallery.svg
  :target: https://coveralls.io/r/aldryn/aldryn-gallery


Aldryn Gallery is build on the principle of plugin-in-plugin provided by django-cms 
since version 3.0.

The gallery requires **jQuery** and `classjs <https://github.com/finalangel/classjs-plugins>`_ cl.gallery.
